jQuery UI Tooltip - Custom content

## St. Stephen's Cathedral

### Vienna, Austria

## Tower Bridge

### London, England

All images are part of Wikimedia Commons and are licensed under CC BY-SA 3.0 by the copyright holder.

Shows how to combine different event delegated tooltips into a single instance, by customizing the items and content options.

We realize you may want to interact with the map tooltips. This is a planned feature for a future version.